@@ -1,7 +1,8 @@
 import numpy as np
-from typing import Callable, Sequence, Tuple
+from typing import Callable, Sequence, Tuple, List
 from hcmioptim._optim_types import Number, ObjectiveFunc
 from multiprocessing import Pool
+import itertools as it
 NextGenFunc = Callable[[Sequence[Tuple[Number, np.ndarray]]], Sequence[np.ndarray]]
 
 
@@ -20,9 +21,9 @@ class GAOptimizer:
                      and return a vector of encodings to be the next generation.
         starting_population: The population of encodings that the optimizer begins with.
         remember_cost: If True, the optimizer saves the cost of each encoding that passes
-                          through the cost function. If a encoding has already been through,
-                          the cost function is not run and the saved value is returned. If False,
-                          the cost function is run each time.
+                       through the cost function. If a encoding has already been through,
+                       the cost function is not run and the saved value is returned. If False,
+                       the cost function is run each time.
         """
         self._objective = objective
         self._next_gen_fn = next_gen_fn
@@ -39,7 +40,8 @@ class GAOptimizer:
             with Pool(self._num_processes) as p:
                 cost_to_encoding = p.map(_rate_encoding,
                                          ((self._call_objective, encoding)
-                                          for encoding in self._population))
+                                          for encoding in self._population),
+                                         len(self._population)//self._num_processes)
         self._population = self._next_gen_fn(cost_to_encoding)
         return cost_to_encoding
 
@@ -72,7 +74,8 @@ def _calc_cost_selection_probs(costs: np.ndarray) -> np.ndarray:
 def roulette_wheel_cost_selection(cost_to_encoding: Sequence[Tuple[Number, np.ndarray]])\
         -> Tuple[Tuple[np.ndarray, np.ndarray], ...]:
     """
-    Create a sequence of pairings of encodings to crossover using the roulette wheel selection method.
+    Create a sequence of pairings of encodings to crossover using
+    the roulette wheel selection method.
     This uses cost weighting.
     """
     P_n = _calc_cost_selection_probs(np.array(tuple(x[0] for x in cost_to_encoding)))
@@ -90,7 +93,8 @@ def roulette_wheel_cost_selection(cost_to_encoding: Sequence[Tuple[Number, np.nd
 def roulette_wheel_rank_selection(cost_to_encoding: Sequence[Tuple[Number, np.ndarray]])\
         -> Tuple[Tuple[np.ndarray, np.ndarray], ...]:
     """
-    Create a sequence of pairings of encodings to crossover using the roulette wheel selection method.
+    Create a sequence of pairings of encodings to crossover using
+    the roulette wheel selection method.
     This uses rank weighting.
     """
     sorted_ftg = sorted(cost_to_encoding, key=lambda x: x[0])
